@@ -18,6 +18,28 @@
  * Software Foundation; either version 2, or (at your option) any later 
  * version.
  * 
+ * Linking GNU Smalltalk statically or dynamically with other modules is
+ * making a combined work based on GNU Smalltalk.  Thus, the terms and
+ * conditions of the GNU General Public License cover the whole
+ * combination.
+ *
+ * In addition, as a special exception, the Free Software Foundation
+ * give you permission to combine GNU Smalltalk with free software
+ * programs or libraries that are released under the GNU LGPL and with
+ * independent programs running under the GNU Smalltalk virtual machine.
+ *
+ * You may copy and distribute such a system following the terms of the
+ * GNU GPL for GNU Smalltalk and the licenses of the other code
+ * concerned, provided that you include the source code of that other
+ * code when and as the GNU GPL requires distribution of source code.
+ *
+ * Note that people who make modified versions of GNU Smalltalk are not
+ * obligated to grant this special exception for their modified
+ * versions; it is their choice whether to do so.  The GNU General
+ * Public License gives permission to release a modified version without
+ * this exception; this exception also makes it possible to release a
+ * modified version which carries forward this exception.
+ *
  * GNU Smalltalk is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
@@ -541,7 +563,6 @@ _gst_init_cfuncs (void)
   /* regex routines */
   _gst_define_cfunc ("reh_search", _gst_re_search);
   _gst_define_cfunc ("reh_match", _gst_re_match);
-  _gst_define_cfunc ("reh_free_registers", _gst_re_free_registers);
   _gst_define_cfunc ("reh_make_cacheable", _gst_re_make_cacheable);
 
   /* Non standard routines */
@@ -665,7 +686,7 @@ _gst_invoke_croutine (OOP cFuncOOP,
   for (si = i = 0; i < fixedArgs; i++)
     {
       cType = TO_INT (desc->argTypes[i]);
-      if (cType >= CDATA_SELF)
+      if (cType == CDATA_SELF || cType == CDATA_SELF_OOP)
 	push_smalltalk_obj (receiver,
 			    cType == CDATA_SELF ? CDATA_UNKNOWN : CDATA_OOP);
       else if (cType != CDATA_VOID)
