@@ -10,7 +10,7 @@
 
 /***********************************************************************
  *
- * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002
+ * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002,2006
  * Free Software Foundation, Inc.
  * Written by Steve Byrne.
  *
@@ -21,6 +21,28 @@
  * Software Foundation; either version 2, or (at your option) any later
  * version.
  *
+ * Linking GNU Smalltalk statically or dynamically with other modules is
+ * making a combined work based on GNU Smalltalk.  Thus, the terms and
+ * conditions of the GNU General Public License cover the whole
+ * combination.
+ *
+ * In addition, as a special exception, the Free Software Foundation
+ * give you permission to combine GNU Smalltalk with free software
+ * programs or libraries that are released under the GNU LGPL and with
+ * independent programs running under the GNU Smalltalk virtual machine.
+ *
+ * You may copy and distribute such a system following the terms of the
+ * GNU GPL for GNU Smalltalk and the licenses of the other code
+ * concerned, provided that you include the source code of that other
+ * code when and as the GNU GPL requires distribution of source code.
+ *
+ * Note that people who make modified versions of GNU Smalltalk are not
+ * obligated to grant this special exception for their modified
+ * versions; it is their choice whether to do so.  The GNU General
+ * Public License gives permission to release a modified version without
+ * this exception; this exception also makes it possible to release a
+ * modified version which carries forward this exception.
+ *
  * GNU Smalltalk is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
@@ -484,7 +506,7 @@ static mst_Boolean unwind_method (void);
    or an unwind method.  In this case the non-unwind contexts between
    the unwind method and the returnContextOOP must be removed from the
    chain.  */
-static void unwind_to (OOP returnContextOOP);
+static mst_Boolean unwind_to (OOP returnContextOOP);
 
 /* Arrange things so that all the non-unwinding contexts up to
    returnContextOOP aren't executed.  For block contexts this can
@@ -493,7 +515,7 @@ static void unwind_to (OOP returnContextOOP);
    from them!  For this reason, method contexts are flagged as
    disabled and unwind_context takes care of skipping them when
    doing a local return.  */
-static void disable_non_unwind_contexts (OOP returnContextOOP);
+static mst_Boolean disable_non_unwind_contexts (OOP returnContextOOP);
 
 /* Called to handle signals that are not passed to the Smalltalk
    program, such as interrupts or segmentation violation.  In the
@@ -671,7 +693,7 @@ static gst_context_part *chunk = chunks - 1;
    and as long as no context switches happen since the time the
    process was created.  FREE_LIFO_CONTEXT points to just after the
    top of the stack.  */
-static struct OOP lifo_contexts[MAX_LIFO_DEPTH] CACHELINE_ALIGNED;
+static struct oop_s lifo_contexts[MAX_LIFO_DEPTH] CACHELINE_ALIGNED;
 static OOP free_lifo_context = lifo_contexts;
 
 /* Include `plug-in' modules for the appropriate interpreter.
@@ -887,7 +909,7 @@ dealloc_stack_context (gst_context_part context)
 {
 #ifndef OPTIMIZE
   if (free_lifo_context == lifo_contexts
-      || (OOP_TO_OBJ (free_lifo_context - 1) != (mst_Object) context))
+      || (OOP_TO_OBJ (free_lifo_context - 1) != (gst_object) context))
     {
       _gst_errorf ("Deallocating a non-LIFO context!!!");
       abort ();
@@ -979,7 +1001,7 @@ _gst_find_method (OOP receiverClass,
 OOP
 create_args_array (int numArgs)
 {
-  mst_Object argsArray;
+  gst_object argsArray;
   OOP argsArrayOOP;
   int i;
 
@@ -1120,12 +1142,11 @@ unwind_method (void)
       return (false);
     }
 
-  unwind_to (newContext->parentContext);
-  return (true);
+  return unwind_to (newContext->parentContext);
 }
 
 
-void
+mst_Boolean
 unwind_to (OOP returnContextOOP)
 {
   OOP oldContextOOP, newContextOOP;
@@ -1148,15 +1169,16 @@ unwind_to (OOP returnContextOOP)
       /* Check if we got to an unwinding context (#ensure:).  */
       if UNCOMMON (CONTEXT_FLAGS (newContext) & MCF_IS_UNWIND_CONTEXT)
         {
+	  mst_Boolean result;
 	  _gst_this_context_oop = oldContextOOP;
 
 	  /* _gst_this_context_oop is the context above the
 	     one we return to.   We only unwind up to the #ensure:
 	     context.  */
-	  disable_non_unwind_contexts (returnContextOOP);
+	  result = disable_non_unwind_contexts (returnContextOOP);
 
 	  unwind_context ();
-	  return;
+	  return result;
 	}
 
       /* This context cannot be deallocated in a LIFO way.  We must
@@ -1191,9 +1213,10 @@ unwind_to (OOP returnContextOOP)
   _gst_self = newContext->receiver;
 
   SET_THIS_METHOD (newContext->method, GET_CONTEXT_IP (newContext));
+  return (true);
 }
 
-void
+mst_Boolean
 disable_non_unwind_contexts (OOP returnContextOOP)
 {
   OOP oldContextOOP, newContextOOP, *chain;
@@ -1218,6 +1241,12 @@ disable_non_unwind_contexts (OOP returnContextOOP)
 	   collect more context objects.  */
         oldContext->parentContext = _gst_nil_oop;
 
+      if (IS_NIL (newContextOOP))
+	{
+	  *chain = newContextOOP;
+	  return (false);
+	}
+
       if (newContextOOP == returnContextOOP)
 	{
 	  *chain = newContextOOP;
@@ -1255,6 +1284,7 @@ disable_non_unwind_contexts (OOP returnContextOOP)
     }
 
   *chain = newContext->parentContext;
+  return (true);
 }
 
 
@@ -1941,7 +1971,7 @@ _gst_init_process_system (void)
   processor = (gst_processor_scheduler) OOP_TO_OBJ (_gst_processor_oop);
   if (IS_NIL (processor->processLists))
     {
-      mst_Object processLists;
+      gst_object processLists;
 
       processLists = instantiate_with (_gst_array_class, NUM_PRIORITIES,
 				       &processor->processLists);
@@ -2240,8 +2270,6 @@ void
 _gst_mark_processor_registers (void)
 {
   mark_semaphore_oops ();
-
-  /* Get everything into the main OOP table first.  */
   if (_gst_this_context_oop)
     MAYBE_MARK_OOP (_gst_this_context_oop);
 
@@ -2434,7 +2462,8 @@ interrupt_handler (int sig)
 #ifdef HAVE_EXECINFO_H
       /* Don't print a backtrace, for example, if exiting during a
 	 compilation.  */
-      if (ip || _gst_gc_running || is_serious_error || sig == SIGUSR1)
+      if ((_gst_verbosity > 2 && (ip || _gst_gc_running))
+	  || is_serious_error || sig == SIGUSR1)
 	{
           PTR array[11];
           size_t size = backtrace (array, 11);
